#
# example of how to interrogate a range of QuadLN_S boards individually
# Robin Becker
# Jul 11 2022
#

import jmri
import jmri.jmrit.roster

#define range of QuadLN_S Board Addresses to be interrogated
qlnsFirstAddressToInterrogate = 11010
qlnsLastAddressToInterrogate = 11199

# class that does the interrogation work
class Interrogate(jmri.jmrit.automat.AbstractAutomaton) :
  def __init__(self) :
    self.cmd = 0
    self.addrList=[]
    self.index = 0
    return

  def addAddr(self,addr) :
    if(addr not in self.addrList)  :
      self.addrList.append(addr)
    return

  # cycle through the 8 interrogate steps for each board address
  def handle(self) :
    # if starting new cycle, get next board address
    if(self.cmd == 0) :
      # if no more addresses, then exit
      if(self.index >= len(self.addrList)) :
        return False
      addr = self.addrList[self.index]
      self.index += 1
      self.programmer = jmri.InstanceManager.getDefault(jmri.AddressedProgrammerManager).getAddressedProgrammer(addr, addr)
    self.programmer.writeCV("7", self.cmd, None)
    self.waitMsec(50)
    # move to next cmd in the cycle
    self.cmd += 1
    if (self.cmd >=  8) :
      self.cmd = 0
    return True

# get the roster list
# the list of None's means match everything
rosterlist = jmri.jmrit.roster.Roster.getDefault().matchingList(None, None, None, None, None, None, None)

# create an instance of the interrogate class
a = Interrogate()

# build a list of QuadLN_S addresses to interrogate
for entry in rosterlist.toArray() :
  addr = int(entry.getDccAddress())
  if (addr >= qlnsFirstAddressToInterrogate and addr <= qlnsLastAddressToInterrogate) :
    a.addAddr(addr)
    
# start interrogation of each QuadLN_S board in the list
a.start()